Installation
============

Install ``pytest-regressions`` using ``pip``::

    $ pip install pytest-regressions

If you want to use the ``dataframe``, ``num`` or ``image`` fixtures, you can
choose to install the correct dependencies by passing one or a list of their names as an extra::

    $ pip install pytest-regressions[dataframe,num,image]

Or if you are using ``conda``::

    $ conda install -c conda-forge pytest-regressions
